# Azure Blob Explorer for Python
[![FOSSA Status](https://app.fossa.io/api/projects/git%2Bgithub.com%2Fakshaybabloo%2Fazure-blob-explorer-python.svg?type=shield)](https://app.fossa.io/projects/git%2Bgithub.com%2Fakshaybabloo%2Fazure-blob-explorer-python?ref=badge_shield)


## Instillation

Using PIP

```bash
pip install azblobexplorer
```

Using source

```bash
python setup.py install
```

## Usage

Please see the documentation at [https://akshaybabloo.github.io/azure-blob-explorer-python/](https://akshaybabloo.github.io/azure-blob-explorer-python/)

## Contributions

All contributions are welcome.


## License
[![FOSSA Status](https://app.fossa.io/api/projects/git%2Bgithub.com%2Fakshaybabloo%2Fazure-blob-explorer-python.svg?type=large)](https://app.fossa.io/projects/git%2Bgithub.com%2Fakshaybabloo%2Fazure-blob-explorer-python?ref=badge_large)